from django.db import models
from websites.models import Website


class Company(models.Model):
    name = models.CharField(max_length=200, verbose_name="企业名称")
    category = models.CharField(max_length=100, verbose_name="公司类别:这家企业是干啥的", null=True, blank=True)
    size = models.CharField(max_length=50, verbose_name="公司规模", null=True, blank=True)
    introduction = models.TextField(verbose_name="企业介绍")
    address = models.CharField(max_length=300, verbose_name="企业地址")
    benefits = models.TextField(blank=True, verbose_name="企业福利", null=True)
    website = models.ForeignKey(
        Website,
        on_delete=models.CASCADE,
        related_name="companies",
        verbose_name="隶属网站"
    )
    company_type = models.CharField(max_length=100, verbose_name="企业类型:私企民营:国企外企等", null=True, blank=True)
    founded_date = models.CharField(max_length=100, verbose_name="创办时间", null=True, blank=True)
    created_at = models.DateTimeField(auto_now_add=True, verbose_name="入库时间", null=True)
    updated_at = models.DateTimeField(auto_now=True, verbose_name="更新时间", null=True)

    def __str__(self):
        return self.name

    class Meta:
        verbose_name = "企业"
        verbose_name_plural = "企业列表"
        unique_together = (("name", "website"),)